; === IR_echo2.bas ============ 2009.03.12 ============ Ron Hackett ===

;	This TankBot program runs on a PICAXE-08M slave processor at 8 MHz.
;	It emits 42 kHz IR PWM bursts & checks for echoes after each burst.

; =====================================================================


; === Constants ====

	symbol LED_L = 0				;  left obstacle warning on output 0 (pin 7)
	symbol LED_R = 1				; right obstacle warning on output 1 (pin 6)
	symbol IRout = 2				; IR LED on PWM output 2 (pin 5)
	
	symbol  abit = 40				; used to slow down program execution speed
	symbol	reps = 5				; used to decrease false-posiive echoes
		
; NOTE:	
; The output of the  left IR detector is connected to input 4 (pin 3)
; The output of the right IR detector is connected to input 3 (pin 4)

	 	 	 
; === Variables ====

	symbol echoes = b0					; used to store echo values
	symbol echo_L = bit4				; used to access  left echo data
	symbol echo_R = bit3				; used to access right echo data
	symbol  eLeft = b1					; left-side echo counter
	symbol eRight = b2					; right-side echo counter
	symbol  index = b3					; used in for...next loop


; === Directives ===

	#com2												; specify serial port
	#picaxe 08M									; specify PICAXE processor	


; === Begin Main Program ==============================================

	setfreq m8						 			; set internal resonator to 8 MHz
															; (4 MHz is too slow to capture echoes)
	let dirs = %00000111				; set pins 4 and 3 as inputs
										 					; set pins 2,1 & 0 as outputs
										 					
	 do													; The following is an infinite loop
	   eLeft  = 0								; initialize the  left echo counter
	   eRight = 0								; initialize the right echo counter
	   	      
	   for index = 1 to reps		; check for echo after each PWM burst
	     pwmout IRout,47,95			; PWM burst detuned to 42 kHz, 50% DS
	     pause 40								; transmit IR PWM for 20 mS
	     pwmout IRout off				; PWM off
	     echoes = pins					; capture echoes
	     
	     if echo_L = 0 then			; if echo on left then
	        inc eLeft						;    increment eLeft   
	     endif
	     
	     if echo_R = 0 then			; if echo on right then
	        inc eRight					;    increment eRight    
	     endif
	     
	     pause abit							; slow it dowqn a little
	   next index
	 
	   if eLeft = reps then			; if valid obstacle on left then
	     	high LED_L						;    set left warning output
	  	else										; else
	     	low LED_L							;    clear left warning output
	  	endif

	  	if eRight = reps then		; if valid obstacle on right then
	     	high LED_R						;    set right warning output
	  	else										; else
	     	low LED_R							;    clear right warning output
	  	endif

	 loop												; loop forever



